from setuptools import setup, find_packages

setup(
    name='is-x-py',
    version='0.0.1',
    packages=find_packages(),
    install_requires=[],
    author='Dang Pham',
    author_email='danghuuphamusf@gmail.com',
    description='Python implementation of is-x library',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/deidaraiorek/is-x/packages/is-x-py',
    classifiers=[
        'Programming Language :: Python :: 3',
    ],
)
